netapp_ontap.models.nvme_subsystem_controller_dh_hmac_chap API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_subsystem_controller_dh_hmac_chap`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeSubsystemControllerDhHmacChapSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeSubsystemControllerDhHmacChap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `group_size: str GET`

    The Diffie-Hellman group size used for NVMe in-band authentication. This property is populated only when NVMe in-band authentication was performed for the NVMe-oF transport connection.

    Valid choices:

    - none
    - 2048_bit
    - 3072_bit
    - 4096_bit
    - 6144_bit
    - 8192_bit
  `hash_function: str GET`

    The hash function used for NVMe in-band authentication. This property is populated only when NVMe in-band authentication was performed for the NVMe-oF transport connection.

    Valid choices:

    - sha_256
    - sha_512
  `mode: str GET`

    The NVMe in-band authentication mode used for the host connection. When set to: - none: Neither the host nor controller was authenticated. - unidirectional: The controller authenticated the host. - bidirectional: The controller authenticated the host and the host authenticated the controller.

    Valid choices:

    - none
    - unidirectional
    - bidirectional